@@ -600,9 +600,11 @@ sub select__static_files {
 
 #print STDERR "\$filename = '$filename' (1)\n";
 	
-	my $v = '_' . $Zanas::VERSION_NAME;	
+	my $v = '_' . $Zanas_VERSION_NAME;
 	$filename =~ s{$v}{}i;
 
+	$filename =~ s{_00000\d+(\.[a-z]{2,3})$}{$1};
+
 #print STDERR "\$v = '$v'\n";
 #print STDERR "\$filename = '$filename' (2)\n";
 	
@@ -984,6 +986,7 @@ sub fill_in {
 		confirm_close_vocabulary => ' ',
 		session_terminated       => ' ',
 		save_or_cancel           => ',    (Ctrl-Enter)    (Esc)',
+		infty                    => '&infin;', 
    	});
    	
    	fill_in_i18n ('ENG', {
@@ -1012,6 +1015,7 @@ sub fill_in {
 		confirm_close_vocabulary => 'Your choice is',
 		session_terminated       => 'Logged off',
 		save_or_cancel           => 'Please save your data (Ctrl-Enter) or cancel pending input (Esc)',
+		infty                    => '&infin;', 
    	});
 	
    	fill_in_i18n ('FRE', {
@@ -1040,6 +1044,7 @@ sub fill_in {
 		confirm_close_vocabulary => 'Vous avez choisi',
 		session_terminated       => 'Dconnetc',
 		save_or_cancel           => "Veuillez sauvegarder vos donnes (Ctrl-Enter) ou bien alluler l'opration (Esc)",
+		infty                    => '&infin;', 
    	});   	
 
 }
@@ -1079,4 +1084,23 @@ sub fill_in_button_presets {
 
 };
 
+################################################################################
+
+sub get_ids {
+
+	my ($name) = @_;
+	
+	$name .= '_';
+	
+	my @ids = ();
+	
+	while (my ($key, $value) = each %_REQUEST) {
+		$key =~ /$name(\d+)/ or next;
+		push @ids, $1;
+	}
+	
+	return @ids;	
+
+}
+
 1;
\ No newline at end of file
